@@ -1,5 +1,6 @@
 import htmlentitydefs, re
 
+
 def unescape(text):
     def fixup(m):
         text = m.group(0)
@@ -20,3 +21,14 @@ def unescape(text):
                 pass
         return text # leave as is
     return re.sub("&#?\w+;", fixup, text)
+
+
+def text_table(soup_table, table_printer, skip_row=0):
+    t = table_printer
+
+    rows = soup_table.findAll('tr')[skip_row:]
+    for r in rows:
+        cells = r.findAll('td')
+        t.add_row([unescape(c.text) for c in cells])
+
+    return t
